from __future__ import annotations

from crashtest.contracts.solution import Solution


class BaseSolution(Solution):
    def __init__(self, title: str = "", description: str = "") -> None:
        self._title = title
        self._description = description
        self._links: list[str] = []

    @property
    def solution_title(self) -> str:
        return self._title

    @property
    def solution_description(self) -> str:
        return self._description

    @property
    def documentation_links(self) -> list[str]:
        return self._links



from __future__ import annotations

from typing import TYPE_CHECKING


if TYPE_CHECKING:
    from crashtest.contracts.solution import Solution


class HasSolutionsForException:
    def can_solve(self, exception: Exception) -> bool:
        raise NotImplementedError()

    def get_solutions(self, exception: Exception) -> list[Solution]:
        raise NotImplementedError()
